@@ -54,7 +54,7 @@ private:
 /************ VARIABLES **************/
     // One int to rule them all! (for-loops)
     int i;
-    // int j is used in copyToOthers(), called functions from copyTOOthers() use int i
+    // int j is used in copyToOthers(), called functions from copyToOthers() use int i
     int j;
 
     QString* fileWithPath;
@@ -66,7 +66,6 @@ private:
     QFile saveFile;
     QTextStream fileContent;
 
-    // The paths for all the images
     QList<QString*> imgPath;
 
     // Buttons for loading images (main screen)
@@ -103,6 +102,7 @@ private:
 
     // The menu and its actions
     QMenu* ismMenu;
+    QAction* ismMenuActionReset;
     QAction* ismMenuActionAbout;
 
     // The overwrite dialog with its contents
@@ -116,9 +116,15 @@ private:
         QPushButton* owNo;
 
     // The About dialog with its contents
+    bool aboutDialogExists;
     QDialog* aboutDialog;
+        QLabel* aboutIcon;
         QLabel* aboutText;
-        QHBoxLayout* aboutHLayout;
+        QPushButton* aboutOK;
+        QVBoxLayout* aboutLayoutV1;
+        QVBoxLayout* aboutLayoutV2;
+        QVBoxLayout* aboutLayoutV3;
+        QHBoxLayout* aboutLayoutH;
 
 public slots:
     // Slots for imgBtn#, these slots open openImage()
@@ -127,6 +133,7 @@ public slots:
     void clickedImgBtn2();
     void clickedImgBtn3();
 
+    // This also updates nameEditLower, which is the filename
     void updateSaveBtn();
     void setSaveFile();
 
@@ -140,8 +147,10 @@ public slots:
 
     void confirmOverwrite();
 
-    // Copies image info from source (int)
     void copyToOthers();
+
+    // Empty everything
+    void resetScreen();
 };
 
 #endif // IMAGESETMAKER_H
