@@ -4,7 +4,7 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    //Q_INIT_RESOURCE(imageResource);
+    Q_INIT_RESOURCE(imagesetmakerRsrc);
     imageSetMaker ismWindow;
 
 #if defined(Q_WS_S60)
